@@ -219,11 +219,6 @@ protected:
   //----------------------------------------------------------------------------
   void configureSwiftParams();
 
-  //----------------------------------------------------------------------------
-  // Configure request for Reva.
-  //----------------------------------------------------------------------------
-  void configureRevaParams();
-
   //----------------------------------------------------------------------------
   // Set-up deadline, but only if uninitialized
   //----------------------------------------------------------------------------
