@@ -1,6 +1,7 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) 2013  Adrien Devresse <adrien.devresse@cern.ch>, CERN
+ * Copyright (C) CERN 2013
+ * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,9 +40,12 @@ const std::string scope_main = "Davix::Tools::davix-mkcol";
 
 
 
-static std::string help_msg(){
-    return Tool::get_base_description_options() +
-            Tool::get_common_options();
+static std::string help_msg(const std::string & cmd_path){
+    std::string help_msg = fmt::format("Usage : {} ", cmd_path);
+    help_msg += Tool::get_base_description_options();
+    help_msg += Tool::get_common_options();
+
+    return help_msg;
 }
 
 
@@ -50,23 +54,19 @@ int main(int argc, char** argv){
     int retcode=-1;
     Tool::OptParams opts;
     DavixError* tmp_err=NULL;
-    opts.help_msg = help_msg();
+    opts.help_msg = help_msg(argv[0]);
 
     if( (retcode= Tool::parse_davix_options(argc, argv, opts, &tmp_err)) ==0){
         Context c;
         if( (retcode = Tool::configureAuth(opts)) == 0){
-            configureContext(c, opts);
-            DavFile f(c,opts.vec_arg[0]);
-            f.makeCollection(&opts.params, &tmp_err);
+            if(checkProtocolSanity(opts, opts.vec_arg[0], &tmp_err)) {
+              configureContext(c, opts);
+              DavFile f(c,opts.vec_arg[0]);
+              f.makeCollection(&opts.params, &tmp_err);
+              if(tmp_err) retcode = -1;
+            }
         }
     }
     Tool::errorPrint(&tmp_err);
     return retcode;
 }
-
-
-
-
-
-
-
